@@ -1,6 +1,7 @@
 import ctypes
 
-from sys import platform
+import sys
+import platform
 from os import path
 
 from . import constants
@@ -9,7 +10,13 @@ from . import constants
 lib_name = "libcontrast_c"
 if path.exists("/etc/alpine-release"):
     lib_name += "_musl"
-lib_ext = ".dylib" if platform.startswith("darwin") else ".so"
-lib_path = "".join([path.dirname(__file__), "/libs/", lib_name, lib_ext])
 
+if sys.platform.startswith("darwin"):
+    lib_ext = ".dylib"
+    if "arm64" in platform.machine():
+        lib_name += "_arm64"
+else:
+    lib_ext = ".so"
+
+lib_path = "".join([path.dirname(__file__), "/libs/", lib_name, lib_ext])
 lib_contrast = ctypes.cdll.LoadLibrary(lib_path)
